package com.huashe.park.core.mapper;

import com.huashe.park.domain.entity.ParkInspectProj;

import java.util.List;


/**
 * 巡检项Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-06
 */
public interface ParkInspectProjMapper 
{
    /**
     * 查询巡检项
     * 
     * @param id 巡检项主键
     * @return 巡检项
     */
    public ParkInspectProj selectParkInspectProjById(Long id);

    /**
     * 查询巡检项列表
     * 
     * @param parkInspectProj 巡检项
     * @return 巡检项集合
     */
    public List<ParkInspectProj> selectParkInspectProjList(ParkInspectProj parkInspectProj);

    /**
     * 新增巡检项
     * 
     * @param parkInspectProj 巡检项
     * @return 结果
     */
    public int insertParkInspectProj(ParkInspectProj parkInspectProj);

    /**
     * 修改巡检项
     * 
     * @param parkInspectProj 巡检项
     * @return 结果
     */
    public int updateParkInspectProj(ParkInspectProj parkInspectProj);

    /**
     * 删除巡检项
     * 
     * @param id 巡检项主键
     * @return 结果
     */
    public int deleteParkInspectProjById(Long id);

    /**
     * 批量删除巡检项
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteParkInspectProjByIds(Long[] ids);
}
